@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import List
+from typing import Any, Dict, List
 
 from .literals import (
     AdditionalConstraintsElementType,
@@ -46,51 +46,77 @@ __all__ = (
     "BackendAPIResourceConfigTypeDef",
     "BackendAuthSocialProviderConfigTypeDef",
     "BackendJobRespObjTypeDef",
-    "CloneBackendResponseTypeDef",
-    "CreateBackendAPIResponseTypeDef",
+    "CloneBackendRequestTypeDef",
+    "CloneBackendResponseResponseTypeDef",
+    "CreateBackendAPIRequestTypeDef",
+    "CreateBackendAPIResponseResponseTypeDef",
     "CreateBackendAuthForgotPasswordConfigTypeDef",
     "CreateBackendAuthIdentityPoolConfigTypeDef",
     "CreateBackendAuthMFAConfigTypeDef",
     "CreateBackendAuthOAuthConfigTypeDef",
     "CreateBackendAuthPasswordPolicyConfigTypeDef",
+    "CreateBackendAuthRequestTypeDef",
     "CreateBackendAuthResourceConfigTypeDef",
-    "CreateBackendAuthResponseTypeDef",
+    "CreateBackendAuthResponseResponseTypeDef",
     "CreateBackendAuthUserPoolConfigTypeDef",
-    "CreateBackendConfigResponseTypeDef",
-    "CreateBackendResponseTypeDef",
-    "CreateTokenResponseTypeDef",
-    "DeleteBackendAPIResponseTypeDef",
-    "DeleteBackendAuthResponseTypeDef",
-    "DeleteBackendResponseTypeDef",
-    "DeleteTokenResponseTypeDef",
+    "CreateBackendConfigRequestTypeDef",
+    "CreateBackendConfigResponseResponseTypeDef",
+    "CreateBackendRequestTypeDef",
+    "CreateBackendResponseResponseTypeDef",
+    "CreateTokenRequestTypeDef",
+    "CreateTokenResponseResponseTypeDef",
+    "DeleteBackendAPIRequestTypeDef",
+    "DeleteBackendAPIResponseResponseTypeDef",
+    "DeleteBackendAuthRequestTypeDef",
+    "DeleteBackendAuthResponseResponseTypeDef",
+    "DeleteBackendRequestTypeDef",
+    "DeleteBackendResponseResponseTypeDef",
+    "DeleteTokenRequestTypeDef",
+    "DeleteTokenResponseResponseTypeDef",
     "EmailSettingsTypeDef",
-    "GenerateBackendAPIModelsResponseTypeDef",
-    "GetBackendAPIModelsResponseTypeDef",
-    "GetBackendAPIResponseTypeDef",
-    "GetBackendAuthResponseTypeDef",
-    "GetBackendJobResponseTypeDef",
-    "GetBackendResponseTypeDef",
-    "GetTokenResponseTypeDef",
-    "ImportBackendAuthResponseTypeDef",
-    "ListBackendJobsResponseTypeDef",
+    "GenerateBackendAPIModelsRequestTypeDef",
+    "GenerateBackendAPIModelsResponseResponseTypeDef",
+    "GetBackendAPIModelsRequestTypeDef",
+    "GetBackendAPIModelsResponseResponseTypeDef",
+    "GetBackendAPIRequestTypeDef",
+    "GetBackendAPIResponseResponseTypeDef",
+    "GetBackendAuthRequestTypeDef",
+    "GetBackendAuthResponseResponseTypeDef",
+    "GetBackendJobRequestTypeDef",
+    "GetBackendJobResponseResponseTypeDef",
+    "GetBackendRequestTypeDef",
+    "GetBackendResponseResponseTypeDef",
+    "GetTokenRequestTypeDef",
+    "GetTokenResponseResponseTypeDef",
+    "ImportBackendAuthRequestTypeDef",
+    "ImportBackendAuthResponseResponseTypeDef",
+    "ListBackendJobsRequestTypeDef",
+    "ListBackendJobsResponseResponseTypeDef",
     "LoginAuthConfigReqObjTypeDef",
     "PaginatorConfigTypeDef",
-    "RemoveAllBackendsResponseTypeDef",
-    "RemoveBackendConfigResponseTypeDef",
+    "RemoveAllBackendsRequestTypeDef",
+    "RemoveAllBackendsResponseResponseTypeDef",
+    "RemoveBackendConfigRequestTypeDef",
+    "RemoveBackendConfigResponseResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "SettingsTypeDef",
     "SmsSettingsTypeDef",
     "SocialProviderSettingsTypeDef",
-    "UpdateBackendAPIResponseTypeDef",
+    "UpdateBackendAPIRequestTypeDef",
+    "UpdateBackendAPIResponseResponseTypeDef",
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     "UpdateBackendAuthIdentityPoolConfigTypeDef",
     "UpdateBackendAuthMFAConfigTypeDef",
     "UpdateBackendAuthOAuthConfigTypeDef",
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
+    "UpdateBackendAuthRequestTypeDef",
     "UpdateBackendAuthResourceConfigTypeDef",
-    "UpdateBackendAuthResponseTypeDef",
+    "UpdateBackendAuthResponseResponseTypeDef",
     "UpdateBackendAuthUserPoolConfigTypeDef",
-    "UpdateBackendConfigResponseTypeDef",
-    "UpdateBackendJobResponseTypeDef",
+    "UpdateBackendConfigRequestTypeDef",
+    "UpdateBackendConfigResponseResponseTypeDef",
+    "UpdateBackendJobRequestTypeDef",
+    "UpdateBackendJobResponseResponseTypeDef",
 )
 
 BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
@@ -174,21 +200,17 @@ class BackendJobRespObjTypeDef(
     pass
 
 
-CloneBackendResponseTypeDef = TypedDict(
-    "CloneBackendResponseTypeDef",
+CloneBackendRequestTypeDef = TypedDict(
+    "CloneBackendRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
-        "Error": str,
-        "JobId": str,
-        "Operation": str,
-        "Status": str,
+        "TargetEnvironmentName": str,
     },
-    total=False,
 )
 
-CreateBackendAPIResponseTypeDef = TypedDict(
-    "CreateBackendAPIResponseTypeDef",
+CloneBackendResponseResponseTypeDef = TypedDict(
+    "CloneBackendResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -196,8 +218,31 @@ CreateBackendAPIResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateBackendAPIRequestTypeDef = TypedDict(
+    "CreateBackendAPIRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
+        "ResourceName": str,
+    },
+)
+
+CreateBackendAPIResponseResponseTypeDef = TypedDict(
+    "CreateBackendAPIResponseResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "Error": str,
+        "JobId": str,
+        "Operation": str,
+        "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
@@ -299,6 +344,16 @@ class CreateBackendAuthPasswordPolicyConfigTypeDef(
     pass
 
 
+CreateBackendAuthRequestTypeDef = TypedDict(
+    "CreateBackendAuthRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "CreateBackendAuthResourceConfigTypeDef",
+        "ResourceName": str,
+    },
+)
+
 _RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthResourceConfigTypeDef",
     {
@@ -322,8 +377,8 @@ class CreateBackendAuthResourceConfigTypeDef(
     pass
 
 
-CreateBackendAuthResponseTypeDef = TypedDict(
-    "CreateBackendAuthResponseTypeDef",
+CreateBackendAuthResponseResponseTypeDef = TypedDict(
+    "CreateBackendAuthResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -331,8 +386,8 @@ CreateBackendAuthResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
@@ -361,19 +416,64 @@ class CreateBackendAuthUserPoolConfigTypeDef(
     pass
 
 
-CreateBackendConfigResponseTypeDef = TypedDict(
-    "CreateBackendConfigResponseTypeDef",
+_RequiredCreateBackendConfigRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendConfigRequestTypeDef",
+    {
+        "AppId": str,
+    },
+)
+_OptionalCreateBackendConfigRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendConfigRequestTypeDef",
+    {
+        "BackendManagerAppId": str,
+    },
+    total=False,
+)
+
+
+class CreateBackendConfigRequestTypeDef(
+    _RequiredCreateBackendConfigRequestTypeDef, _OptionalCreateBackendConfigRequestTypeDef
+):
+    pass
+
+
+CreateBackendConfigResponseResponseTypeDef = TypedDict(
+    "CreateBackendConfigResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "JobId": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateBackendRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendRequestTypeDef",
+    {
+        "AppId": str,
+        "AppName": str,
+        "BackendEnvironmentName": str,
+    },
+)
+_OptionalCreateBackendRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendRequestTypeDef",
+    {
+        "ResourceConfig": Dict[str, Any],
+        "ResourceName": str,
     },
     total=False,
 )
 
-CreateBackendResponseTypeDef = TypedDict(
-    "CreateBackendResponseTypeDef",
+
+class CreateBackendRequestTypeDef(
+    _RequiredCreateBackendRequestTypeDef, _OptionalCreateBackendRequestTypeDef
+):
+    pass
+
+
+CreateBackendResponseResponseTypeDef = TypedDict(
+    "CreateBackendResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -381,23 +481,53 @@ CreateBackendResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-CreateTokenResponseTypeDef = TypedDict(
-    "CreateTokenResponseTypeDef",
+CreateTokenRequestTypeDef = TypedDict(
+    "CreateTokenRequestTypeDef",
+    {
+        "AppId": str,
+    },
+)
+
+CreateTokenResponseResponseTypeDef = TypedDict(
+    "CreateTokenResponseResponseTypeDef",
     {
         "AppId": str,
         "ChallengeCode": str,
         "SessionId": str,
         "Ttl": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDeleteBackendAPIRequestTypeDef = TypedDict(
+    "_RequiredDeleteBackendAPIRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+_OptionalDeleteBackendAPIRequestTypeDef = TypedDict(
+    "_OptionalDeleteBackendAPIRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
     },
     total=False,
 )
 
-DeleteBackendAPIResponseTypeDef = TypedDict(
-    "DeleteBackendAPIResponseTypeDef",
+
+class DeleteBackendAPIRequestTypeDef(
+    _RequiredDeleteBackendAPIRequestTypeDef, _OptionalDeleteBackendAPIRequestTypeDef
+):
+    pass
+
+
+DeleteBackendAPIResponseResponseTypeDef = TypedDict(
+    "DeleteBackendAPIResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -405,12 +535,21 @@ DeleteBackendAPIResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DeleteBackendAuthResponseTypeDef = TypedDict(
-    "DeleteBackendAuthResponseTypeDef",
+DeleteBackendAuthRequestTypeDef = TypedDict(
+    "DeleteBackendAuthRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+
+DeleteBackendAuthResponseResponseTypeDef = TypedDict(
+    "DeleteBackendAuthResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -418,12 +557,20 @@ DeleteBackendAuthResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DeleteBackendResponseTypeDef = TypedDict(
-    "DeleteBackendResponseTypeDef",
+DeleteBackendRequestTypeDef = TypedDict(
+    "DeleteBackendRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+    },
+)
+
+DeleteBackendResponseResponseTypeDef = TypedDict(
+    "DeleteBackendResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -431,16 +578,24 @@ DeleteBackendResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DeleteTokenResponseTypeDef = TypedDict(
-    "DeleteTokenResponseTypeDef",
+DeleteTokenRequestTypeDef = TypedDict(
+    "DeleteTokenRequestTypeDef",
+    {
+        "AppId": str,
+        "SessionId": str,
+    },
+)
+
+DeleteTokenResponseResponseTypeDef = TypedDict(
+    "DeleteTokenResponseResponseTypeDef",
     {
         "IsSuccess": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EmailSettingsTypeDef = TypedDict(
@@ -452,8 +607,17 @@ EmailSettingsTypeDef = TypedDict(
     total=False,
 )
 
-GenerateBackendAPIModelsResponseTypeDef = TypedDict(
-    "GenerateBackendAPIModelsResponseTypeDef",
+GenerateBackendAPIModelsRequestTypeDef = TypedDict(
+    "GenerateBackendAPIModelsRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+
+GenerateBackendAPIModelsResponseResponseTypeDef = TypedDict(
+    "GenerateBackendAPIModelsResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -461,45 +625,95 @@ GenerateBackendAPIModelsResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetBackendAPIModelsResponseTypeDef = TypedDict(
-    "GetBackendAPIModelsResponseTypeDef",
+GetBackendAPIModelsRequestTypeDef = TypedDict(
+    "GetBackendAPIModelsRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+
+GetBackendAPIModelsResponseResponseTypeDef = TypedDict(
+    "GetBackendAPIModelsResponseResponseTypeDef",
     {
         "Models": str,
         "Status": StatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetBackendAPIRequestTypeDef = TypedDict(
+    "_RequiredGetBackendAPIRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+_OptionalGetBackendAPIRequestTypeDef = TypedDict(
+    "_OptionalGetBackendAPIRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
     },
     total=False,
 )
 
-GetBackendAPIResponseTypeDef = TypedDict(
-    "GetBackendAPIResponseTypeDef",
+
+class GetBackendAPIRequestTypeDef(
+    _RequiredGetBackendAPIRequestTypeDef, _OptionalGetBackendAPIRequestTypeDef
+):
+    pass
+
+
+GetBackendAPIResponseResponseTypeDef = TypedDict(
+    "GetBackendAPIResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "Error": str,
         "ResourceConfig": "BackendAPIResourceConfigTypeDef",
         "ResourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetBackendAuthResponseTypeDef = TypedDict(
-    "GetBackendAuthResponseTypeDef",
+GetBackendAuthRequestTypeDef = TypedDict(
+    "GetBackendAuthRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+
+GetBackendAuthResponseResponseTypeDef = TypedDict(
+    "GetBackendAuthResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "Error": str,
         "ResourceConfig": "CreateBackendAuthResourceConfigTypeDef",
         "ResourceName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetBackendJobResponseTypeDef = TypedDict(
-    "GetBackendJobResponseTypeDef",
+GetBackendJobRequestTypeDef = TypedDict(
+    "GetBackendJobRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+    },
+)
+
+GetBackendJobResponseResponseTypeDef = TypedDict(
+    "GetBackendJobResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -509,12 +723,33 @@ GetBackendJobResponseTypeDef = TypedDict(
         "Operation": str,
         "Status": str,
         "UpdateTime": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetBackendRequestTypeDef = TypedDict(
+    "_RequiredGetBackendRequestTypeDef",
+    {
+        "AppId": str,
+    },
+)
+_OptionalGetBackendRequestTypeDef = TypedDict(
+    "_OptionalGetBackendRequestTypeDef",
+    {
+        "BackendEnvironmentName": str,
     },
     total=False,
 )
 
-GetBackendResponseTypeDef = TypedDict(
-    "GetBackendResponseTypeDef",
+
+class GetBackendRequestTypeDef(
+    _RequiredGetBackendRequestTypeDef, _OptionalGetBackendRequestTypeDef
+):
+    pass
+
+
+GetBackendResponseResponseTypeDef = TypedDict(
+    "GetBackendResponseResponseTypeDef",
     {
         "AmplifyMetaConfig": str,
         "AppId": str,
@@ -522,23 +757,56 @@ GetBackendResponseTypeDef = TypedDict(
         "BackendEnvironmentList": List[str],
         "BackendEnvironmentName": str,
         "Error": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetTokenResponseTypeDef = TypedDict(
-    "GetTokenResponseTypeDef",
+GetTokenRequestTypeDef = TypedDict(
+    "GetTokenRequestTypeDef",
+    {
+        "AppId": str,
+        "SessionId": str,
+    },
+)
+
+GetTokenResponseResponseTypeDef = TypedDict(
+    "GetTokenResponseResponseTypeDef",
     {
         "AppId": str,
         "ChallengeCode": str,
         "SessionId": str,
         "Ttl": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredImportBackendAuthRequestTypeDef = TypedDict(
+    "_RequiredImportBackendAuthRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "NativeClientId": str,
+        "UserPoolId": str,
+        "WebClientId": str,
+    },
+)
+_OptionalImportBackendAuthRequestTypeDef = TypedDict(
+    "_OptionalImportBackendAuthRequestTypeDef",
+    {
+        "IdentityPoolId": str,
     },
     total=False,
 )
 
-ImportBackendAuthResponseTypeDef = TypedDict(
-    "ImportBackendAuthResponseTypeDef",
+
+class ImportBackendAuthRequestTypeDef(
+    _RequiredImportBackendAuthRequestTypeDef, _OptionalImportBackendAuthRequestTypeDef
+):
+    pass
+
+
+ImportBackendAuthResponseResponseTypeDef = TypedDict(
+    "ImportBackendAuthResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -546,17 +814,43 @@ ImportBackendAuthResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListBackendJobsRequestTypeDef = TypedDict(
+    "_RequiredListBackendJobsRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+    },
+)
+_OptionalListBackendJobsRequestTypeDef = TypedDict(
+    "_OptionalListBackendJobsRequestTypeDef",
+    {
+        "JobId": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "Operation": str,
+        "Status": str,
     },
     total=False,
 )
 
-ListBackendJobsResponseTypeDef = TypedDict(
-    "ListBackendJobsResponseTypeDef",
+
+class ListBackendJobsRequestTypeDef(
+    _RequiredListBackendJobsRequestTypeDef, _OptionalListBackendJobsRequestTypeDef
+):
+    pass
+
+
+ListBackendJobsResponseResponseTypeDef = TypedDict(
+    "ListBackendJobsResponseResponseTypeDef",
     {
         "Jobs": List["BackendJobRespObjTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LoginAuthConfigReqObjTypeDef = TypedDict(
@@ -580,24 +874,63 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-RemoveAllBackendsResponseTypeDef = TypedDict(
-    "RemoveAllBackendsResponseTypeDef",
+_RequiredRemoveAllBackendsRequestTypeDef = TypedDict(
+    "_RequiredRemoveAllBackendsRequestTypeDef",
+    {
+        "AppId": str,
+    },
+)
+_OptionalRemoveAllBackendsRequestTypeDef = TypedDict(
+    "_OptionalRemoveAllBackendsRequestTypeDef",
+    {
+        "CleanAmplifyApp": bool,
+    },
+    total=False,
+)
+
+
+class RemoveAllBackendsRequestTypeDef(
+    _RequiredRemoveAllBackendsRequestTypeDef, _OptionalRemoveAllBackendsRequestTypeDef
+):
+    pass
+
+
+RemoveAllBackendsResponseResponseTypeDef = TypedDict(
+    "RemoveAllBackendsResponseResponseTypeDef",
     {
         "AppId": str,
         "Error": str,
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-RemoveBackendConfigResponseTypeDef = TypedDict(
-    "RemoveBackendConfigResponseTypeDef",
+RemoveBackendConfigRequestTypeDef = TypedDict(
+    "RemoveBackendConfigRequestTypeDef",
+    {
+        "AppId": str,
+    },
+)
+
+RemoveBackendConfigResponseResponseTypeDef = TypedDict(
+    "RemoveBackendConfigResponseResponseTypeDef",
     {
         "Error": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
     },
-    total=False,
 )
 
 SettingsTypeDef = TypedDict(
@@ -627,8 +960,31 @@ SocialProviderSettingsTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBackendAPIResponseTypeDef = TypedDict(
-    "UpdateBackendAPIResponseTypeDef",
+_RequiredUpdateBackendAPIRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendAPIRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceName": str,
+    },
+)
+_OptionalUpdateBackendAPIRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendAPIRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateBackendAPIRequestTypeDef(
+    _RequiredUpdateBackendAPIRequestTypeDef, _OptionalUpdateBackendAPIRequestTypeDef
+):
+    pass
+
+
+UpdateBackendAPIResponseResponseTypeDef = TypedDict(
+    "UpdateBackendAPIResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -636,8 +992,8 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
@@ -689,6 +1045,16 @@ UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     total=False,
 )
 
+UpdateBackendAuthRequestTypeDef = TypedDict(
+    "UpdateBackendAuthRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "ResourceConfig": "UpdateBackendAuthResourceConfigTypeDef",
+        "ResourceName": str,
+    },
+)
+
 _RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredUpdateBackendAuthResourceConfigTypeDef",
     {
@@ -712,8 +1078,8 @@ class UpdateBackendAuthResourceConfigTypeDef(
     pass
 
 
-UpdateBackendAuthResponseTypeDef = TypedDict(
-    "UpdateBackendAuthResponseTypeDef",
+UpdateBackendAuthResponseResponseTypeDef = TypedDict(
+    "UpdateBackendAuthResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -721,8 +1087,8 @@ UpdateBackendAuthResponseTypeDef = TypedDict(
         "JobId": str,
         "Operation": str,
         "Status": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
@@ -736,19 +1102,64 @@ UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBackendConfigResponseTypeDef = TypedDict(
-    "UpdateBackendConfigResponseTypeDef",
+_RequiredUpdateBackendConfigRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendConfigRequestTypeDef",
     {
         "AppId": str,
-        "BackendManagerAppId": str,
-        "Error": str,
+    },
+)
+_OptionalUpdateBackendConfigRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendConfigRequestTypeDef",
+    {
         "LoginAuthConfig": "LoginAuthConfigReqObjTypeDef",
     },
     total=False,
 )
 
-UpdateBackendJobResponseTypeDef = TypedDict(
-    "UpdateBackendJobResponseTypeDef",
+
+class UpdateBackendConfigRequestTypeDef(
+    _RequiredUpdateBackendConfigRequestTypeDef, _OptionalUpdateBackendConfigRequestTypeDef
+):
+    pass
+
+
+UpdateBackendConfigResponseResponseTypeDef = TypedDict(
+    "UpdateBackendConfigResponseResponseTypeDef",
+    {
+        "AppId": str,
+        "BackendManagerAppId": str,
+        "Error": str,
+        "LoginAuthConfig": "LoginAuthConfigReqObjTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateBackendJobRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendJobRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+        "JobId": str,
+    },
+)
+_OptionalUpdateBackendJobRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendJobRequestTypeDef",
+    {
+        "Operation": str,
+        "Status": str,
+    },
+    total=False,
+)
+
+
+class UpdateBackendJobRequestTypeDef(
+    _RequiredUpdateBackendJobRequestTypeDef, _OptionalUpdateBackendJobRequestTypeDef
+):
+    pass
+
+
+UpdateBackendJobResponseResponseTypeDef = TypedDict(
+    "UpdateBackendJobResponseResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -758,6 +1169,6 @@ UpdateBackendJobResponseTypeDef = TypedDict(
         "Operation": str,
         "Status": str,
         "UpdateTime": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
